Module: FoobarTemplates::Core
- Defined in:
- lib/foobar_templates/core/core.rb
Overview
This is the core logic for the app. CLI stuff should eventually get pulled out so the app is neat and the way I do CLI stuff lately.
Defined Under Namespace
Modules: DirToTemplate